==> open-xchange-guard-ui_2.10.3.orig.tar.bz2: open-xchange-guard-ui-2.10.3/oxguard-ui/apps/pgp_mail/toggle-encryption.js <==
define('pgp_mail/toggle-encryption', [
    'io.ox/core/capabilities',
    'gettext!oxguard',
    'settings!oxguard',
    'less!pgp_mail/style'
], function (capabilities, gt, settings) {

    'use strict';

    var ToggleEncryptionView = Backbone.View.extend({
        tagName: 'button',
        initialize: function (model, mailModel) {
            this.mailModel = mailModel;
            this.listenTo(this.model, 'change:encrypt', function (model, val) {
                this.$('i.fa').toggleClass('encrypted', val);
                //gt('Click to enable encryption')
                //gt('Click to disable encryption')
            });
        },
        className: 'toggle-encryption',
        events: {
            'click': 'toggle',
            'change:encrypt': 'changed'
        },
        toggle: function () {
            if (this.encryption_forced) {
                require(['io.ox/core/notifications'], function (notify) {
                    notify.yell('error', gt('Reply must be encrypted'));
                });
            } else {
                this.model.set('encrypt', !this.model.get('encrypt'));
                if (!this.model.get('encrypt')) {  // If removing encryption, check for pgp attachments
                    checkPGPAttachment(this.mailModel);
                }
            }
        },
        forceEncryption: function () {
            this.encryption_forced = true;
            this.model.set('encrypt', true);
            this.render();
        },
        render: function () {
            var guard = false;
            if (window.oxguarddata !== undefined) {
                if (window.oxguarddata.settings !== undefined) {
                    guard = (window.oxguarddata.settings.oxguard === true);
                }
            }
            if (guard || this.encryption_forced) {
                if (!_.device('small')) {
                    this.$el.empty().append(
                        $('<i class="fa fa-2x" aria-hidden="true">')
                            .toggleClass('encrypted', !!this.model.get('encrypt'))
                    );
                    this.$el.attr('title', gt('Enable Encryption'));
                }
            }
            this.listenTo(this.model, 'change:encrypt', function () {
                this.changed();
            });
            if (this.model.get('encrypt')) {
                var view = this.view;
                window.setTimeout(function () {
                    showAttLink(view, false);
                }, 100);
            }
            return this;
        },
        noLinkMail: function (view) {
            this.view = view;
            checkAttLinkView(this.mailModel, view);
        },
        changed: function () {
            this.$el.attr('title', this.model.get('encrypt') ? gt('Disable Encryption') : gt('Enable Encryption'));
            if (this.model && this.model.get('encrypt')) {
                showAttLink(this.view, false);
                checkAttLink(this.mailModel);
                try {
                    var fromArray = this.mailModel.get('from');
                    var from = _.isArray(fromArray[0]) ? fromArray[0][1] : fromArray[1];
                    if (fromArray && window.oxguarddata.primaryEmail !== undefined) {
                        if (window.oxguarddata.primaryEmail !== from) {
                            var warn = settings.get('warnEmailDifferent');
                            if (warn === undefined || warn === false) {
                                displayWarning();
                            }
                        }
                    }
                } catch (e) {
                    console.log(e);
                }
            } else {
                showAttLink(this.view, true);
            }
        }
    });

    // Hide or show mail attachment link
    function showAttLink(view, show) {
        if (view) {
            view.$el.find('.share-attachments').toggleClass('guardDisabled', !show);
        }
    }

    // Check if Mail Attachment link is shown and encryption enabled
    function checkAttLinkView(model, view) {
        if (model.get('share_attachments')) {
            if (model.get('share_attachments').enable) {
                if (model.get('encrypt')) {
                    showAttLink(view, false);
                }
            }
        }
    }

    // Show a warning if Mail Attachment Link is shown and encryption clicked
    function checkAttLink(model) {
        if (model.get('share_attachments')) {
            if (model.get('share_attachments').enable) {
                require(['io.ox/core/tk/dialogs', 'settings!io.ox/mail'], function (dialogs, mail) {
                    var dialog = new dialogs.CreateDialog({ width: 450, height: 300, center: true, enter: 'ok' });
                    dialog.header($('<h4>').text(gt('Not Supported')));
                    var text = $('<p>').text(gt('%s is not supported with secured email and will be disabled.', mail.get('compose/shareAttachments/name')));
                    dialog.getBody().append(text);
                    dialog
                    .addPrimaryButton('ok', gt('OK'), 'ok')
                    .on('ok', function () {
                        $('.share-attachments').find(':checkbox').prop('checked', false);
                        var share = model.get('share_attachments');
                        share.enable = false;
                        model.set('share_attachments', share);
                    })
                    .show();
                });
            }
        }
    }

    // Warning that the from address is different from primary
    function displayWarning() {
        require(['io.ox/core/tk/dialogs'], function (dialogs) {
            var dialog = new dialogs.CreateDialog({ width: 450, height: 300, center: true, enter: 'ok' });
            dialog.header($('<h4>').text(gt('Warning')));
            var text = $('<p>').text(gt('Sending an encrypted email from an account other than %s may cause problems with the recipient being able to reply.  Consider using your primary account.', window.oxguarddata.primaryEmail));
            var warn = $('<input type="checkbox" id="warnEmail">');
            var warntext = $('<span class="selectable" style="padding-left:10px;">').text(gt('Do not warn me again'));
            warntext.click(function () {
                warn.click();
            });
            warn.click(function (e) {
                settings.set('warnEmailDifferent', $(e.target).is(':checked'));
                settings.save();
            });
            dialog.getBody().append(text).append('<hr>').append(warn).append(warntext);
            dialog
            .addPrimaryButton('ok', gt('OK'), 'ok')
            .show();
        });
    }

    // Check to see if there are pgp attachments.  Checked if encryption removed
    // Likely the recipient won't be able to open this attachment if not sent through Guard
    function checkPGPAttachment(model) {
        var attachments = model.get('attachments');
        if (attachments && _.isArray(attachments.models)) {
            attachments.models.forEach(function (attModel) {
                if (attModel.get('file-mimetype') === 'application/pgp-encrypted' ||
                    (attModel.get('filename') && attModel.get('filename').indexOf('.pgp') > 0)) {
                    require(['io.ox/core/yell'], function (yell) {
                        //#.  Warning to the user after they removed encryption from an email.  One of the attachments is a pgp item, and it will likely be unreadable to the recipient if they remove encryption
                        yell('warning', gt('Sending encrypted attachments without encrypting the email will usually result in the attachment being unreadable by the recipient.'));
                    });
                }
            });
        }
    }

    return {
        View: ToggleEncryptionView
    };
});

==> open-xchange-guard-ui_2.10.6.orig.tar.bz2: open-xchange-guard-ui-2.10.6/oxguard-ui/apps/pgp_mail/toggle-encryption.js <==
/**
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * Copyright (C) 2016-2020 OX Software GmbH
 * Author Greg Hill <greg.hill@open-xchange.com>
 */

define('pgp_mail/toggle-encryption', [
    'io.ox/backbone/mini-views/dropdown',
    'io.ox/backbone/mini-views/helplink',
    'oxguard/auth',
    'gettext!oxguard',
    'settings!oxguard',
    'less!pgp_mail/style'
], function (Dropdown, HelpView, auth, gt, settings) {

    'use strict';

    // TODO-784: get rid of
    var ToggleEncryptionView = Backbone.View.extend({
        tagName: 'a',
        className: 'toggle-encryption',
        initialize: function (options) {
            this.mailModel = options.mailModel;
            this.listenTo(this.model, 'change:encrypt', function (model, val) {
                this.$('i.fa').toggleClass('encrypted', val);
                //gt('Click to enable encryption')
                //gt('Click to disable encryption')
            });
        },
        events: {
            'click': 'toggle',
            'change:encrypt': 'changed'
        },
        toggle: function (e) {
            e.preventDefault();
            if (this.encryption_forced) {
                require(['io.ox/core/notifications'], function (notify) {
                    notify.yell('error', gt('Reply must be encrypted'));
                });
            } else {
                var model = this.model;
                if (!model.get('encrypt')) {
                    auth.ensureSetup().then(function () {
                        model.set('encrypt', !model.get('encrypt'));
                        if (!model.get('encrypt')) {  // If removing encryption, check for pgp attachments
                            checkPGPAttachment(this.mailModel);
                        }
                    });
                } else {
                    model.set('encrypt', !model.get('encrypt'));
                }
            }
        },
        forceEncryption: function () {
            this.encryption_forced = true;
            this.model.set('encrypt', true);
            this.render();
        },
        render: function () {
            this.$el.attr('tabindex', '-1');
            var guard = false;
            if (window.oxguarddata !== undefined) {
                if (window.oxguarddata.settings !== undefined) {
                    guard = (window.oxguarddata.settings.oxguard === true);
                }
            }
            if (guard || this.encryption_forced) {
                if (!_.device('small')) {
                    this.$el.empty().append(
                        $('<i class="fa fa-2x" aria-hidden="true">')
                            .toggleClass('encrypted', !!this.model.get('encrypt'))
                    );
                    this.$el.attr('title', gt('Enable Encryption')).attr('href', '#').attr('role', 'button');
                }
            }
            this.listenTo(this.model, 'change:encrypt', function () {
                this.changed();
            });
            if (this.model.get('encrypt')) {
                var view = this.view;
                window.setTimeout(function () {
                    showAttLink(view, false);
                }, 100);
            }
            return this;
        },
        noLinkMail: function (view) {
            this.view = view;
            checkAttLinkView(this.mailModel, view);
        },
        changed: function () {
            this.$el.attr('title', this.model.get('encrypt') ? gt('Disable Encryption') : gt('Enable Encryption'));
            if (this.model && this.model.get('encrypt')) {
                showAttLink(this.view, false);
                checkAttLink(this.mailModel);
                try {
                    var fromArray = this.mailModel.get('from');
                    var from = _.isArray(fromArray[0]) ? fromArray[0][1] : fromArray[1];
                    if (fromArray && window.oxguarddata.primaryEmail !== undefined) {
                        if (window.oxguarddata.primaryEmail !== from) {
                            var warn = settings.get('warnEmailDifferent');
                            if (warn === undefined || warn === false) {
                                displayWarning();
                            }
                        }
                    }
                } catch (e) {
                    console.log(e);
                }
            } else {
                showAttLink(this.view, true);
            }
        }
    });

    // TODO-784: get rid of
    var ToggleEncryptionViewMobile = Backbone.View.extend({
        tagName: 'button',
        initialize: function (model, mailModel) {
            this.mailModel = mailModel;
            this.listenTo(this.model, 'change:encrypt', function (model, val) {
                this.$('i.fa').toggleClass('encrypted', val);
                //gt('Click to enable encryption')
                //gt('Click to disable encryption')
            });
        },
        className: 'toggle-encryption',
        events: {
            'click': 'toggle',
            'change:encrypt': 'changed'
        },
        toggle: function () {
            if (this.encryption_forced) {
                require(['io.ox/core/notifications'], function (notify) {
                    notify.yell('error', gt('Reply must be encrypted'));
                });
            } else {
                var model = this.model;
                if (!model.get('encrypt')) {
                    auth.ensureSetup().then(function () {
                        model.set('encrypt', !model.get('encrypt'));
                        if (!model.get('encrypt')) {  // If removing encryption, check for pgp attachments
                            checkPGPAttachment(this.mailModel);
                        }
                    });
                } else {
                    model.set('encrypt', !model.get('encrypt'));
                }
            }
        },
        forceEncryption: function () {
            this.encryption_forced = true;
            this.model.set('encrypt', true);
            this.render();
        },
        render: function () {
            this.$el.attr('tabindex', '-1');
            var guard = false;
            if (window.oxguarddata !== undefined) {
                if (window.oxguarddata.settings !== undefined) {
                    guard = (window.oxguarddata.settings.oxguard === true);
                }
            }
            if (guard || this.encryption_forced) {
                if (!_.device('small')) {
                    this.$el.empty().append(
                        $('<i class="fa fa-2x" aria-hidden="true">')
                            .toggleClass('encrypted', !!this.model.get('encrypt'))
                    );
                    this.$el.attr('title', gt('Enable Encryption'));
                }
            }
            this.listenTo(this.model, 'change:encrypt', function () {
                this.changed();
            });
            if (this.model.get('encrypt')) {
                var view = this.view;
                window.setTimeout(function () {
                    showAttLink(view, false);
                }, 100);
            }
            return this;
        },
        noLinkMail: function (view) {
            this.view = view;
            checkAttLinkView(this.mailModel, view);
        },
        changed: function () {
            this.$el.attr('title', this.model.get('encrypt') ? gt('Disable Encryption') : gt('Enable Encryption'));
            if (this.model && this.model.get('encrypt')) {
                showAttLink(this.view, false);
                checkAttLink(this.mailModel);
                try {
                    var fromArray = this.mailModel.get('from');
                    var from = _.isArray(fromArray[0]) ? fromArray[0][1] : fromArray[1];
                    if (fromArray && window.oxguarddata.primaryEmail !== undefined) {
                        if (window.oxguarddata.primaryEmail !== from) {
                            var warn = settings.get('warnEmailDifferent');
                            if (warn === undefined || warn === false) {
                                displayWarning();
                            }
                        }
                    }
                } catch (e) {
                    console.log(e);
                }
            } else {
                showAttLink(this.view, true);
            }
        }
    });

    // Hide or show mail attachment link
    function showAttLink(view, show) {
        if (view) {
            view.$('.attachments').toggleClass('guard-encrypted', !show);
        }
    }

    // Check if Mail Attachment link is shown and encryption enabled
    function checkAttLinkView(model, view) {
        if (model.get('share_attachments')) {
            if (model.get('share_attachments').enable) {
                if (model.get('encrypt')) {
                    showAttLink(view, false);
                }
            }
        }
    }

    // Show a warning if Mail Attachment Link is shown and encryption clicked
    function checkAttLink(model) {
        if (model.get('sharedAttachments')) {
            if (model.get('sharedAttachments').enabled) {
                require(['io.ox/core/tk/dialogs', 'settings!io.ox/mail'], function (dialogs, mail) {
                    var dialog = new dialogs.CreateDialog({ width: 450, height: 300, center: true, enter: 'ok' });
                    dialog.header($('<h4>').text(gt('Not Supported')));
                    var text = $('<p>').text(gt('%s is not supported with secured email and will be disabled.', mail.get('compose/shareAttachments/name')));
                    dialog.getBody().append(text);
                    dialog
                    .addPrimaryButton('ok', gt('OK'), 'ok')
                    .on('ok', function () {
                        $('.share-attachments').find(':checkbox').prop('checked', false);
                        var share = model.get('sharedAttachments');
                        share.enabled = false;
                        model.set('sharedAttachments', share);
                    })
                    .show();
                });
            }
        }
    }

    // Warning that the from address is different from primary
    function displayWarning() {
        require(['io.ox/core/tk/dialogs'], function (dialogs) {
            var dialog = new dialogs.CreateDialog({ width: 450, height: 300, center: true, enter: 'ok' });
            dialog.header($('<h4>').text(gt('Warning')));
            var text = $('<p>').text(gt('Sending an encrypted email from an account other than %s may cause problems with the recipient being able to reply.  Consider using your primary account.', window.oxguarddata.primaryEmail));
            var warn = $('<input type="checkbox" id="warnEmail">');
            var warntext = $('<span class="selectable" style="padding-left:10px;">').text(gt('Do not warn me again'));
            warntext.click(function () {
                warn.click();
            });
            warn.click(function (e) {
                settings.set('warnEmailDifferent', $(e.target).is(':checked'));
                settings.save();
            });
            dialog.getBody().append(text).append('<hr>').append(warn).append(warntext);
            dialog
            .addPrimaryButton('ok', gt('OK'), 'ok')
            .show();
        });
    }

    // Check to see if there are pgp attachments.  Checked if encryption removed
    // Likely the recipient won't be able to open this attachment if not sent through Guard
    function checkPGPAttachment(model) {
        var attachments = model.get('attachments');
        if (attachments && _.isArray(attachments.models)) {
            attachments.models.forEach(function (attModel) {
                if (attModel.get('file-mimetype') === 'application/pgp-encrypted' ||
                    (attModel.get('filename') && attModel.get('filename').indexOf('.pgp') > 0)) {
                    require(['io.ox/core/yell'], function (yell) {
                        //#.  Warning to the user after they removed encryption from an email.  One of the attachments is a pgp item, and it will likely be unreadable to the recipient if they remove encryption
                        yell('warning', gt('Sending encrypted attachments without encrypting the email will usually result in the attachment being unreadable by the recipient.'));
                    });
                }
            });
        }
    }

    return {
        View: ToggleEncryptionView,
        ViewMobile: ToggleEncryptionViewMobile
    };
});
